@@ -1,73 +1,70 @@
-from pettingzoo.atari import (
-    basketball_pong_v2,
-    boxing_v1,
-    combat_plane_v1,
-    combat_tank_v1,
-    double_dunk_v2,
-    entombed_competitive_v2,
-    entombed_cooperative_v2,
-    flag_capture_v1,
-    foozpong_v2,
-    ice_hockey_v1,
-    joust_v2,
-    mario_bros_v2,
-    maze_craze_v2,
-    othello_v2,
-    pong_v2,
-    quadrapong_v3,
-    space_invaders_v1,
-    space_war_v1,
-    surround_v1,
-    tennis_v2,
-    video_checkers_v3,
-    volleyball_pong_v2,
-    warlords_v2,
-    wizard_of_wor_v2,
-)
-from pettingzoo.butterfly import (
-    cooperative_pong_v3,
-    knights_archers_zombies_v7,
-    pistonball_v4,
-    prison_v3,
-    prospector_v4,
-)
-from pettingzoo.classic import (
-    backgammon_v3,
-    checkers_v3,
-    chess_v4,
-    connect_four_v3,
-    dou_dizhu_v4,
-    gin_rummy_v4,
-    go_v5,
-    hanabi_v4,
-    leduc_holdem_v4,
-    mahjong_v4,
-    rps_v2,
-    texas_holdem_no_limit_v5,
-    texas_holdem_v4,
-    tictactoe_v3,
-    uno_v4,
-)
-from pettingzoo.magent import (
-    adversarial_pursuit_v3,
-    battle_v3,
-    battlefield_v3,
-    combined_arms_v5,
-    gather_v3,
-    tiger_deer_v3,
-)
-from pettingzoo.mpe import (
-    simple_adversary_v2,
-    simple_crypto_v2,
-    simple_push_v2,
-    simple_reference_v2,
-    simple_speaker_listener_v3,
-    simple_spread_v2,
-    simple_tag_v2,
-    simple_v2,
-    simple_world_comm_v2,
-)
-from pettingzoo.sisl import multiwalker_v7, pursuit_v3, waterworld_v3
+from pettingzoo.atari import basketball_pong_v2
+from pettingzoo.atari import boxing_v1
+from pettingzoo.atari import combat_plane_v1
+from pettingzoo.atari import combat_tank_v1
+from pettingzoo.atari import double_dunk_v2
+from pettingzoo.atari import entombed_competitive_v2
+from pettingzoo.atari import entombed_cooperative_v2
+from pettingzoo.atari import flag_capture_v1
+from pettingzoo.atari import foozpong_v2
+from pettingzoo.atari import ice_hockey_v1
+from pettingzoo.atari import joust_v2
+from pettingzoo.atari import mario_bros_v2
+from pettingzoo.atari import maze_craze_v2
+from pettingzoo.atari import othello_v2
+from pettingzoo.atari import pong_v2
+from pettingzoo.atari import quadrapong_v3
+from pettingzoo.atari import space_invaders_v1
+from pettingzoo.atari import space_war_v1
+from pettingzoo.atari import surround_v1
+from pettingzoo.atari import tennis_v2
+from pettingzoo.atari import video_checkers_v3
+from pettingzoo.atari import volleyball_pong_v2
+from pettingzoo.atari import wizard_of_wor_v2
+from pettingzoo.atari import warlords_v2
+
+from pettingzoo.classic import chess_v4
+from pettingzoo.classic import checkers_v3
+from pettingzoo.classic import rps_v2
+from pettingzoo.classic import connect_four_v3
+from pettingzoo.classic import tictactoe_v3
+from pettingzoo.classic import leduc_holdem_v4
+from pettingzoo.classic import mahjong_v4
+from pettingzoo.classic import texas_holdem_v4
+from pettingzoo.classic import texas_holdem_no_limit_v5
+from pettingzoo.classic import uno_v4
+from pettingzoo.classic import dou_dizhu_v4
+from pettingzoo.classic import gin_rummy_v4
+from pettingzoo.classic import go_v5
+from pettingzoo.classic import hanabi_v4
+from pettingzoo.classic import backgammon_v3
+
+from pettingzoo.butterfly import knights_archers_zombies_v7
+from pettingzoo.butterfly import pistonball_v4
+from pettingzoo.butterfly import cooperative_pong_v3
+from pettingzoo.butterfly import prison_v3
+from pettingzoo.butterfly import prospector_v4
+
+from pettingzoo.magent import battle_v3
+from pettingzoo.magent import adversarial_pursuit_v3
+from pettingzoo.magent import gather_v3
+from pettingzoo.magent import combined_arms_v5
+from pettingzoo.magent import tiger_deer_v3
+from pettingzoo.magent import battlefield_v3
+
+from pettingzoo.mpe import simple_adversary_v2
+from pettingzoo.mpe import simple_crypto_v2
+from pettingzoo.mpe import simple_push_v2
+from pettingzoo.mpe import simple_reference_v2
+from pettingzoo.mpe import simple_speaker_listener_v3
+from pettingzoo.mpe import simple_spread_v2
+from pettingzoo.mpe import simple_tag_v2
+from pettingzoo.mpe import simple_world_comm_v2
+from pettingzoo.mpe import simple_v2
+
+from pettingzoo.sisl import pursuit_v3
+from pettingzoo.sisl import waterworld_v3
+from pettingzoo.sisl import multiwalker_v7
 
 all_prefixes = ["atari", "classic", "butterfly", "magent", "mpe", "sisl"]
 
@@ -77,7 +74,7 @@ manual_environments = {
     "butterfly/cooperative_pong",
     "butterfly/prison",
     "butterfly/prospector",
-    "sisl/pursuit",
+    "sisl/pursuit"
 }
 
 all_environments = {
@@ -105,6 +102,7 @@ all_environments = {
     "atari/volleyball_pong_v2": volleyball_pong_v2,
     "atari/wizard_of_wor_v2": wizard_of_wor_v2,
     "atari/warlords_v2": warlords_v2,
+
     "classic/chess_v4": chess_v4,
     "classic/checkers_v3": checkers_v3,
     "classic/rps_v2": rps_v2,
@@ -120,17 +118,20 @@ all_environments = {
     "classic/go_v5": go_v5,
     "classic/hanabi_v4": hanabi_v4,
     "classic/backgammon_v3": backgammon_v3,
+
     "butterfly/knights_archers_zombies_v7": knights_archers_zombies_v7,
     "butterfly/pistonball_v4": pistonball_v4,
     "butterfly/cooperative_pong_v3": cooperative_pong_v3,
     "butterfly/prison_v3": prison_v3,
     "butterfly/prospector_v4": prospector_v4,
+
     "magent/adversarial_pursuit_v3": adversarial_pursuit_v3,
     "magent/battle_v3": battle_v3,
     "magent/battlefield_v3": battlefield_v3,
     "magent/combined_arms_v5": combined_arms_v5,
     "magent/gather_v3": gather_v3,
     "magent/tiger_deer_v3": tiger_deer_v3,
+
     "mpe/simple_adversary_v2": simple_adversary_v2,
     "mpe/simple_crypto_v2": simple_crypto_v2,
     "mpe/simple_push_v2": simple_push_v2,
@@ -140,6 +141,7 @@ all_environments = {
     "mpe/simple_tag_v2": simple_tag_v2,
     "mpe/simple_world_comm_v2": simple_world_comm_v2,
     "mpe/simple_v2": simple_v2,
+
     "sisl/multiwalker_v7": multiwalker_v7,
     "sisl/waterworld_v3": waterworld_v3,
     "sisl/pursuit_v3": pursuit_v3,
